@@ -40,7 +40,6 @@ AppItem::AppItem(const QGSettings *appSettings, const QGSettings *activeAppSetti
     , m_itemEntryInter(new DockEntryInter("com.deepin.dde.daemon.Dock", entry.path(), QDBusConnection::sessionBus(), this))
     , m_swingEffectView(nullptr)
     , m_itemAnimation(nullptr)
-    , m_wmHelper(DWindowManagerHelper::instance())
     , m_drag(nullptr)
     , m_dragging(false)
     , m_retryTimes(0)
@@ -62,6 +61,7 @@ AppItem::AppItem(const QGSettings *appSettings, const QGSettings *activeAppSetti
 
     m_id = m_itemEntryInter->id();
     m_active = m_itemEntryInter->isActive();
+    m_currentWindowId = m_itemEntryInter->currentWindow();
 
     m_updateIconGeometryTimer->setInterval(500);
     m_updateIconGeometryTimer->setSingleShot(true);
@@ -77,9 +77,8 @@ AppItem::AppItem(const QGSettings *appSettings, const QGSettings *activeAppSetti
     connect(m_itemEntryInter, &DockEntryInter::WindowInfosChanged, this, &AppItem::updateWindowInfos, Qt::QueuedConnection);
     connect(m_itemEntryInter, &DockEntryInter::IconChanged, this, &AppItem::refreshIcon);
 
-    connect(m_updateIconGeometryTimer, &QTimer::timeout, this, &AppItem::updateWindowIconGeometries, Qt::QueuedConnection);
     connect(m_retryObtainIconTimer, &QTimer::timeout, this, &AppItem::refreshIcon, Qt::QueuedConnection);
-
+    connect(m_updateIconGeometryTimer, &QTimer::timeout, this, &AppItem::updateWindowIconGeometries, Qt::QueuedConnection);
     connect(this, &AppItem::requestUpdateEntryGeometries, this, &AppItem::updateWindowIconGeometries);
 
     updateWindowInfos(m_itemEntryInter->windowInfos());
@@ -121,12 +120,14 @@ bool AppItem::isValid() const
 // window behaviors like minimization.
 void AppItem::updateWindowIconGeometries()
 {
-    // wayland没做处理
-    if (Utils::IS_WAYLAND_DISPLAY)
-        return;
-
     const QRect r(mapToGlobal(QPoint(0, 0)),
                   mapToGlobal(QPoint(width(), height())));
+
+    if (Utils::IS_WAYLAND_DISPLAY) {
+        Q_EMIT requestUpdateItemMinimizedGeometry(r);
+        return;
+    }
+
     if (!QX11Info::connection()) {
         qWarning() << "QX11Info::connection() is 0x0";
         return;
@@ -412,9 +413,8 @@ void AppItem::leaveEvent(QEvent *e)
     DockItem::leaveEvent(e);
 
     if (m_appPreviewTips) {
-        if (m_appPreviewTips->isVisible()) {
+        if (m_appPreviewTips->isVisible())
             m_appPreviewTips->prepareHide();
-        }
     }
 }
 
@@ -455,9 +455,8 @@ QWidget *AppItem::popupTips()
     appNameTips.setObjectName(m_itemEntryInter->name());
 
     if (!m_windowInfos.isEmpty()) {
-        const quint32 currentWindow = m_itemEntryInter->currentWindow();
-        Q_ASSERT(m_windowInfos.contains(currentWindow));
-        appNameTips.setText(m_windowInfos[currentWindow].title.simplified());
+        Q_ASSERT(m_windowInfos.contains(m_currentWindowId));
+        appNameTips.setText(m_windowInfos[m_currentWindowId].title.simplified());
     } else {
         appNameTips.setText(m_itemEntryInter->name().simplified());
     }
@@ -485,9 +484,69 @@ QPoint AppItem::appIconPosition() const
     return QPoint(iconX, iconY);
 }
 
+void AppItem::showPopupWindow(QWidget *const content, const bool model, const int radius)
+{
+    PopupWindow->setRadius(radius);
+
+    m_popupShown = true;
+    m_lastPopupWidget = content;
+
+    if (model)
+        emit requestWindowAutoHide(false);
+
+    DockPopupWindow *popup = PopupWindow.data();
+    QWidget *lastContent = popup->getContent();
+    if (lastContent)
+        lastContent->setVisible(false);
+
+    switch (DockPosition) {
+    case Top:   popup->setArrowDirection(DockPopupWindow::ArrowTop);     break;
+    case Bottom: popup->setArrowDirection(DockPopupWindow::ArrowBottom);  break;
+    case Left:  popup->setArrowDirection(DockPopupWindow::ArrowLeft);    break;
+    case Right: popup->setArrowDirection(DockPopupWindow::ArrowRight);   break;
+    }
+    popup->resize(content->sizeHint());
+
+    if(m_wmHelper->hasComposite()) {
+        PopupWindow->setRadiusArrowStyleEnable(true);
+        if(DockPosition == Position::Bottom || DockPosition == Position::Top) {
+            if(m_appPreviewTips) {
+                PopupWindow->setArrowWidth(40);
+                PopupWindow->setArrowHeight(25);
+            } else {
+                PopupWindow->setArrowWidth(14);
+                PopupWindow->setArrowHeight(10);
+            }
+        } else {
+            if(m_appPreviewTips) {
+                PopupWindow->setArrowWidth(40);
+                PopupWindow->setArrowHeight(25);
+            } else {
+                PopupWindow->setArrowWidth(14);
+                PopupWindow->setArrowHeight(10);
+            }
+        }
+    } else {
+        PopupWindow->setRadiusArrowStyleEnable(false);
+        PopupWindow->setArrowWidth(20);
+        PopupWindow->setArrowHeight(10);
+    }
+
+    popup->setContent(content);
+
+    const QPoint p = popupMarkPoint();
+    if (!popup->isVisible())
+        QMetaObject::invokeMethod(popup, "show", Qt::QueuedConnection, Q_ARG(QPoint, p), Q_ARG(bool, model));
+    else
+        popup->show(p, model);
+
+    connect(popup, &DockPopupWindow::accept, this, &AppItem::popupWindowAccept, Qt::UniqueConnection);
+}
+
 void AppItem::updateWindowInfos(const WindowInfoMap &info)
 {
     m_windowInfos = info;
+    m_currentWindowId = info.isEmpty() ? 0 :  info.firstKey();
     if (m_appPreviewTips)
         m_appPreviewTips->setWindowInfos(m_windowInfos, m_itemEntryInter->GetAllowedCloseWindows().value());
     m_updateIconGeometryTimer->start();
@@ -499,7 +558,14 @@ void AppItem::updateWindowInfos(const WindowInfoMap &info)
     } else {
         stopSwingEffect();
     }
+    update();
+}
 
+void AppItem::updateSnapSize()
+{
+    if (m_appPreviewTips) {
+        m_appPreviewTips->fetchSnapshots();
+    }
     update();
 }
 
@@ -562,6 +628,7 @@ void AppItem::onResetPreview()
     if (m_appPreviewTips != nullptr) {
         m_appPreviewTips->deleteLater();
         m_appPreviewTips = nullptr;
+        disconnect(m_itemEntryInter, &DockEntryInter::WindowInfosChanged, this, &AppItem::updateSnapSize);
     }
 }
 
@@ -578,6 +645,7 @@ void AppItem::showPreview()
     m_appPreviewTips = new PreviewContainer;
     m_appPreviewTips->updateDockSize(DockSize);
     m_appPreviewTips->setWindowInfos(m_windowInfos, m_itemEntryInter->GetAllowedCloseWindows().value());
+    m_appPreviewTips->fetchSnapshots();
     m_appPreviewTips->updateLayoutDirection(DockPosition);
 
     connect(m_appPreviewTips, &PreviewContainer::requestActivateWindow, this, &AppItem::requestActivateWindow, Qt::QueuedConnection);
@@ -589,6 +657,7 @@ void AppItem::showPreview()
     connect(m_appPreviewTips, &PreviewContainer::requestActivateWindow, this, &AppItem::onResetPreview);
     connect(m_appPreviewTips, &PreviewContainer::requestCancelPreviewWindow, this, &AppItem::onResetPreview);
     connect(m_appPreviewTips, &PreviewContainer::requestHidePopup, this, &AppItem::onResetPreview);
+    connect(m_itemEntryInter, &DockEntryInter::WindowInfosChanged, this, &AppItem::updateSnapSize, Qt::QueuedConnection);
 
     // 预览标题显示方式的配置
     DConfig *config = DConfig::create("org.deepin.dde.dock", "org.deepin.dde.dock");
