@@ -40,14 +40,15 @@ public:
     inline ItemType itemType() const override { return App; }
     QPixmap appIcon(){ return m_appIcon; }
     virtual QString accessibleName() override;
+    inline quint32 getAppItemWindowId() const { return  m_currentWindowId; }
 
 signals:
     void requestActivateWindow(const WId wid) const;
     void requestPreviewWindow(const WId wid) const;
     void requestCancelPreview() const;
     void dragReady(QWidget *dragWidget);
-
     void requestUpdateEntryGeometries() const;
+    void requestUpdateItemMinimizedGeometry(const QRect) const;
 
 private:
     void moveEvent(QMoveEvent *e) override;
@@ -71,8 +72,11 @@ private:
 
     QPoint appIconPosition() const;
 
+    void showPopupWindow(QWidget *const content, const bool model = false, const int radius = 6) override;
+
 private slots:
     void updateWindowInfos(const WindowInfoMap &info);
+    void updateSnapSize();
     void refreshIcon() override;
     void activeChanged();
     void showPreview();
@@ -97,14 +101,13 @@ private:
     QGraphicsView *m_swingEffectView;
     QGraphicsItemAnimation *m_itemAnimation;
 
-    DWindowManagerHelper *m_wmHelper;
-
     QPointer<AppDrag> m_drag;
 
     bool m_dragging;
     bool m_active;
     int m_retryTimes;
     bool m_iconValid;
+    quint32 m_currentWindowId;
     quint64 m_lastclickTimes;
 
     WindowInfoMap m_windowInfos;
