@@ -8,6 +8,7 @@
 #include "utils.h"
 
 #include <DStyle>
+#include <DGuiApplicationHelper>
 
 #include <X11/Xlib.h>
 #include <X11/X.h>
@@ -37,6 +38,7 @@ struct SHMInfo {
 };
 
 using namespace Dock;
+DGUI_USE_NAMESPACE
 
 AppSnapshot::AppSnapshot(const WId wid, QWidget *parent)
     : QWidget(parent)
@@ -101,7 +103,15 @@ void AppSnapshot::updateTitle()
 
     QFontMetrics fm(m_3DtitleBtn->font());
     int textWidth = fm.width(title()) + 10 + BTN_TITLE_MARGIN;
-    int titleWidth = SNAP_WIDTH - (TITLE_MARGIN * 2  + BORDER_MARGIN);
+
+    bool isHorizontal = qApp->property(PROP_POSITION).value<Dock::Position>() == Dock::Position::Top
+            || qApp->property(PROP_POSITION).value<Dock::Position>() == Dock::Position::Bottom;
+
+    int titleWidth;
+    if (isHorizontal)
+        titleWidth = qMax(m_snapshot.width(), MIN_SNAP_SIZE) - (TITLE_MARGIN * 2 + BORDER_MARGIN);
+    else
+        titleWidth = SNAP_WIDTH_VERTICAL - (TITLE_MARGIN * 2  + BORDER_MARGIN);
 
     if (textWidth  < titleWidth) {
         m_3DtitleBtn->setFixedWidth(textWidth);
@@ -116,7 +126,10 @@ void AppSnapshot::updateTitle()
     }
 
     // 移动到预览图中下
-    m_3DtitleBtn->move(QPoint(SNAP_WIDTH / 2, SNAP_HEIGHT - m_3DtitleBtn->height() / 2 - TITLE_MARGIN) - m_3DtitleBtn->rect().center());
+    if (isHorizontal)
+        m_3DtitleBtn->move(QPoint(SNAP_WIDTH_HORIZONTAL / 2, SNAP_HEIGHT_HORIZONTAL - m_3DtitleBtn->height() / 2 - TITLE_MARGIN) - m_3DtitleBtn->rect().center());
+    else
+        m_3DtitleBtn->move(QPoint(SNAP_WIDTH_VERTICAL / 2, SNAP_HEIGHT_VERTICAL - m_3DtitleBtn->height() / 2 - TITLE_MARGIN) - m_3DtitleBtn->rect().center());
 }
 
 void AppSnapshot::setTitleVisible(bool bVisible)
@@ -170,11 +183,7 @@ void AppSnapshot::setWindowInfo(const WindowInfo &info)
     m_title->setText(strTtile);
     m_title->adjustSize();
 
-    // 设置单个预览界面大小
-    if (m_wmHelper->hasComposite()) {
-        setMinimumSize(SNAP_WIDTH, SNAP_HEIGHT);
-        setFixedSize(SNAP_WIDTH, SNAP_HEIGHT);
-    } else {
+    if (!m_wmHelper->hasComposite()) {
         setMinimumSize(m_title->width() + SNAP_CLOSE_BTN_WIDTH + 2 * SNAP_CLOSE_BTN_MARGIN, SNAP_HEIGHT_WITHOUT_COMPOSITE);
     }
 
@@ -194,6 +203,48 @@ void AppSnapshot::dragEnterEvent(QDragEnterEvent *e)
         emit entered(m_wid);
 }
 
+void AppSnapshot::updateSnapshotSize()
+{
+    bool isHorizontal = qApp->property(PROP_POSITION).value<Dock::Position>() == Dock::Position::Top
+            || qApp->property(PROP_POSITION).value<Dock::Position>() == Dock::Position::Bottom;
+
+    if(isHorizontal) {
+        m_snapshot = m_snapshot.scaledToHeight(SNAP_HEIGHT_HORIZONTAL, Qt::SmoothTransformation);
+    } else {
+        m_snapshot = m_snapshot.scaledToWidth(SNAP_WIDTH_VERTICAL, Qt::SmoothTransformation);
+    }
+
+    m_snapshotSrcRect = m_snapshot.rect();
+
+    if(isHorizontal) {
+        //状态栏在上下
+        if(m_snapshot.width() > SNAP_WIDTH_HORIZONTAL) {
+            m_snapshot = m_snapshot.scaledToWidth(SNAP_WIDTH_HORIZONTAL);
+            setFixedSize(SNAP_WIDTH_HORIZONTAL, SNAP_HEIGHT_HORIZONTAL);
+            m_snapshotSrcRect.setWidth(SNAP_WIDTH_HORIZONTAL - BORDER_MARGIN * 2 - 0.5);
+            m_snapshotSrcRect.setHeight(m_snapshot.height() - BORDER_MARGIN * 2 - 0.5);
+        } else {
+            setFixedSize(qMax(m_snapshot.width(), MIN_SNAP_SIZE), SNAP_HEIGHT_HORIZONTAL);
+            m_snapshotSrcRect.setWidth(m_snapshot.width() - BORDER_MARGIN * 2 - 0.5);
+            m_snapshotSrcRect.setHeight(SNAP_HEIGHT_HORIZONTAL - BORDER_MARGIN * 2 - 0.5);
+        }
+    } else {
+        //状态栏在左右
+        if(m_snapshot.height() > SNAP_HEIGHT_VERTICAL) {
+            m_snapshot = m_snapshot.scaledToHeight(SNAP_HEIGHT_VERTICAL);
+            setFixedSize(SNAP_WIDTH_VERTICAL, SNAP_HEIGHT_VERTICAL);
+            m_snapshotSrcRect.setWidth(m_snapshot.width() - BORDER_MARGIN * 2 - 0.5);
+            m_snapshotSrcRect.setHeight(SNAP_HEIGHT_VERTICAL - BORDER_MARGIN * 2 - 0.5);
+        } else {
+            setFixedSize(SNAP_WIDTH_VERTICAL, qMax(m_snapshot.height(), MIN_SNAP_SIZE));
+            m_snapshotSrcRect.setWidth(SNAP_WIDTH_VERTICAL - BORDER_MARGIN * 2 - 0.5);
+            m_snapshotSrcRect.setHeight(m_snapshot.height() - BORDER_MARGIN * 2 - 0.5);
+        }
+    }
+
+    update();
+}
+
 void AppSnapshot::fetchSnapshot()
 {
     if (!m_wmHelper->hasComposite())
@@ -212,19 +263,19 @@ void AppSnapshot::fetchSnapshot()
 
             QList<QVariant> args;
             args << QVariant::fromValue(m_wid);
-            args << QVariant::fromValue(quint32(SNAP_WIDTH));
-            args << QVariant::fromValue(quint32(SNAP_HEIGHT));
+            args << QVariant::fromValue(quint32(SNAP_WIDTH_HORIZONTAL));
+            args << QVariant::fromValue(quint32(SNAP_HEIGHT_HORIZONTAL));
 
             QDBusReply<QString> reply = interface.callWithArgumentList(QDBus::Block,QStringLiteral("screenshotForWindowExtend"), args);
-            if(reply.isValid()){
+            if (reply.isValid()) {
                 const QString tmpFile = reply.value();
                 if (QFile::exists(tmpFile)) {
                     m_snapshot.load(tmpFile);
-                    m_snapshotSrcRect = m_snapshot.rect();
+
                     qDebug() << "reply: " << tmpFile;
                     QFile::remove(tmpFile);
                     break;
-                }  else {
+                } else {
                     qDebug() << "get current workspace bckground error, file does not exist : " << tmpFile;
                 }
             } else {
@@ -239,7 +290,6 @@ void AppSnapshot::fetchSnapshot()
             image_data = (uchar *)shmat(info->shmid, 0, 0);
             if ((qint64)image_data != -1) {
                 m_snapshot = QImage(image_data, info->width, info->height, info->bytesPerLine, (QImage::Format)info->format);
-                m_snapshotSrcRect = QRect(info->rect.x, info->rect.y, info->rect.width, info->rect.height);
                 break;
             }
             qDebug() << "invalid pointer of shm!";
@@ -261,36 +311,24 @@ void AppSnapshot::fetchSnapshot()
 
             if (!qimage.isNull()) {
                 m_snapshot = qimage;
-                // remove shadow frame
-                m_snapshotSrcRect = rectRemovedShadow(qimage, nullptr);
+
             } else {
                 qDebug() << "can not get QImage! giving up...";
             }
         }
     } while(false);
 
+    updateSnapshotSize();
+
     // 如果m_snapshot或m_snapshotSrcRect为空，说明三种方式均失败，返回不做处理
     if (m_snapshot.isNull() || m_snapshotSrcRect.isNull()) {
         qWarning() << "can not get QImage or QRectF! giving up...";
         return;
     }
 
-    QSizeF size(rect().marginsRemoved(QMargins(8, 8, 8, 8)).size());
-    const auto ratio = devicePixelRatioF();
-    size = m_snapshotSrcRect.size().scaled(size * ratio, Qt::KeepAspectRatio);
-    qreal scale = qreal(size.width()) / m_snapshotSrcRect.width();
-    m_snapshot = m_snapshot.scaled(qRound(m_snapshot.width() * scale), qRound(m_snapshot.height() * scale),
-                                   Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-    m_snapshotSrcRect.moveTop(m_snapshotSrcRect.top() * scale + 0.5);
-    m_snapshotSrcRect.moveLeft(m_snapshotSrcRect.left() * scale + 0.5);
-    m_snapshotSrcRect.setWidth(size.width() - 0.5);
-    m_snapshotSrcRect.setHeight(size.height() - 0.5);
-
     if (image_data) shmdt(image_data);
     if (ximage) XDestroyImage(ximage);
     if (info) XFree(info);
-
-    update();
 }
 
 void AppSnapshot::enterEvent(QEvent *e)
@@ -331,8 +369,6 @@ void AppSnapshot::paintEvent(QPaintEvent *e)
     if (m_snapshot.isNull())
         return;
 
-    const auto ratio = devicePixelRatioF();
-
     // draw attention background
     if (m_windowInfo.attention) {
         painter.setBrush(QColor(241, 138, 46, 255 * .8));
@@ -341,21 +377,34 @@ void AppSnapshot::paintEvent(QPaintEvent *e)
     }
 
     // draw image
-    const QImage &im = m_snapshot;
-
-    const qreal offset_x = width() / 2.0 - m_snapshotSrcRect.width() / ratio / 2 - m_snapshotSrcRect.left() / ratio;
-    const qreal offset_y = height() / 2.0 - m_snapshotSrcRect.height() / ratio / 2 - m_snapshotSrcRect.top() / ratio;
+    const qreal offset_x = width() / 2.0 - m_snapshotSrcRect.width() / 2 - m_snapshotSrcRect.left();
+    const qreal offset_y = height() / 2.0 - m_snapshotSrcRect.height() / 2 - m_snapshotSrcRect.top();
 
     DStyleHelper dstyle(style());
     const int radius = dstyle.pixelMetric(DStyle::PM_FrameRadius);
 
     QBrush brush;
-    brush.setTextureImage(im);
+    brush.setTextureImage(m_snapshot);
+
+    QColor color;
+    if(DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::ColorType::DarkType) {
+        color = QColor(Qt::black);
+    } else {
+        color = QColor(Qt::white);
+    }
+
+    //绘制预览图背景
+    const QRectF rectSnap = rect().marginsRemoved(QMargins(BORDER_MARGIN, BORDER_MARGIN, BORDER_MARGIN, BORDER_MARGIN));
+    color.setAlphaF(0.2);
+    painter.setPen(Qt::NoPen);
+    painter.setBrush(color);
+    painter.drawRoundedRect(rectSnap, radius, radius);
+
     painter.setBrush(brush);
     painter.setPen(Qt::NoPen);
-    painter.scale(1 / ratio, 1 / ratio);
-    painter.translate(QPoint(offset_x * ratio, offset_y * ratio));
-    painter.drawRoundedRect(m_snapshotSrcRect, radius * ratio, radius * ratio);
+    painter.setRenderHint(QPainter::Antialiasing);
+    painter.translate(QPoint(offset_x, offset_y));
+    painter.drawRoundedRect(m_snapshotSrcRect, radius, radius);
 }
 
 void AppSnapshot::mousePressEvent(QMouseEvent *e)
@@ -384,7 +433,6 @@ bool AppSnapshot::eventFilter(QObject *watched, QEvent *e)
 void AppSnapshot::resizeEvent(QResizeEvent *event)
 {
     QWidget::resizeEvent(event);
-    fetchSnapshot();
 }
 
 SHMInfo *AppSnapshot::getImageDSHM()
