@@ -19,8 +19,14 @@
 DWIDGET_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 
-#define SNAP_WIDTH       200
-#define SNAP_HEIGHT      130
+#define SNAP_WIDTH_HORIZONTAL       240
+#define SNAP_HEIGHT_HORIZONTAL      130
+
+#define SNAP_WIDTH_VERTICAL       185
+#define SNAP_HEIGHT_VERTICAL      200
+
+#define MIN_SNAP_SIZE              80
+
 #define SNAP_HEIGHT_WITHOUT_COMPOSITE       30
 #define SNAP_WIDTH_WITHOUT_COMPOSITE       300
 
@@ -75,6 +81,7 @@ public slots:
     void closeWindow() const;
     void compositeChanged() const;
     void setWindowInfo(const WindowInfo &info);
+    void updateTitle();
 
 private:
     void dragEnterEvent(QDragEnterEvent *e) override;
@@ -88,7 +95,7 @@ private:
     XImage *getImageXlib();
     QRect rectRemovedShadow(const QImage &qimage, unsigned char *prop_to_return_gtk);
     void getWindowState();
-    void updateTitle();
+    void updateSnapshotSize();
 
 private:
     const WId m_wid;
