@@ -8,6 +8,7 @@
 #include <QWidget>
 #include <QPointer>
 
+#include <DLabel>
 #include <DIconButton>
 #include <DPushButton>
 
@@ -41,7 +42,7 @@ private:
     QPointer<AppSnapshot> m_tracked;
 
     DIconButton *m_closeBtn3D;
-    DPushButton *m_titleBtn;
+    DLabel *m_titleLabel;
 };
 
 #endif // FLOATINGPREVIEW_H
