@@ -37,7 +37,6 @@ PreviewContainer::PreviewContainer(QWidget *parent)
     m_windowListWidget = new QWidget(this);
     m_windowListWidget->setAccessibleName("centralLayoutWidget");
     m_windowListWidget->setLayout(m_windowListLayout);
-    m_windowListWidget->setMinimumSize(SNAP_WIDTH, SNAP_HEIGHT);
     m_windowListWidget->installEventFilter(this);
     m_windowListWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_windowListWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -80,13 +79,12 @@ PreviewContainer::PreviewContainer(QWidget *parent)
     m_waitForShowPreviewTimer->setInterval(200);
 
     setAcceptDrops(true);
-    setFixedSize(SNAP_WIDTH, SNAP_HEIGHT);
 
     connect(m_mouseLeaveTimer, &QTimer::timeout, this, &PreviewContainer::checkMouseLeave, Qt::QueuedConnection);
     connect(m_waitForShowPreviewTimer, &QTimer::timeout, this, &PreviewContainer::previewFloating);
 
     // 预览界面在滚动时，暂时不允许预览，避免在滚动时频繁切换预览造成闪屏
-    connect(m_scrollArea->horizontalScrollBar(), &QScrollBar::valueChanged, this, [ = ]{
+    connect(m_scrollArea->horizontalScrollBar(), &QScrollBar::valueChanged, this, [ = ] {
         m_floatingPreview->setVisible(false);
         m_canPreview = false;
         if (m_preparePreviewTimer->isActive()) {
@@ -94,7 +92,7 @@ PreviewContainer::PreviewContainer(QWidget *parent)
         }
         m_preparePreviewTimer->start();
     });
-    connect(m_scrollArea->verticalScrollBar(), &QScrollBar::valueChanged, this, [ = ]{
+    connect(m_scrollArea->verticalScrollBar(), &QScrollBar::valueChanged, this, [ = ] {
         m_floatingPreview->setVisible(false);
         m_canPreview = false;
         if (m_preparePreviewTimer->isActive()) {
@@ -104,7 +102,7 @@ PreviewContainer::PreviewContainer(QWidget *parent)
     });
 
     // 停止滚动后允许预览
-    connect(m_preparePreviewTimer, &QTimer::timeout, this, [ = ]{
+    connect(m_preparePreviewTimer, &QTimer::timeout, this, [ = ] {
         m_canPreview = true;
         if (m_wmHelper->hasComposite()) {
             m_waitForShowPreviewTimer->start();
@@ -137,7 +135,15 @@ void PreviewContainer::setWindowInfos(const WindowInfoMap &infos, const WindowLi
         emit requestCancelPreviewWindow();
         emit requestHidePopup();
     }
+}
 
+void PreviewContainer::fetchSnapshots()
+{
+    for(auto snapshot : m_snapshots) {
+        snapshot->fetchSnapshot();
+        snapshot->updateTitle();
+        m_windowListLayout->addWidget(snapshot);
+    }
     adjustSize(m_wmHelper->hasComposite());
 }
 
@@ -221,17 +227,30 @@ void PreviewContainer::adjustSize(bool composite)
     //先根据屏幕宽高计算出能预览的最大数量,然后根据数量计算界面宽高
     if (composite) {
         if (horizontal) {
-            const int h = SNAP_HEIGHT + MARGIN * 2;
-            const int w = SNAP_WIDTH * count + MARGIN * 2 + SPACING * (count - 1);
-
-            m_windowListWidget->setFixedSize(w, h);
-            setFixedSize(qMin(w, screenWidth), h);
+            //dock栏在上下
+            auto funcWidthSum = [ this ]()-> const int {
+                int snapshotSumWidth = 0;
+                for(auto snapshot : m_snapshots) {
+                    snapshotSumWidth += qMin(qMax(snapshot->width(), MIN_SNAP_SIZE), SNAP_WIDTH_HORIZONTAL);
+                }
+                return snapshotSumWidth;
+            };
+            const int widthSum = funcWidthSum();
+            const int h = SNAP_HEIGHT_HORIZONTAL + MARGIN * 2;
+            m_windowListWidget->setFixedSize(widthSum, h);
+            setFixedSize(qMin(widthSum, screenWidth), h);
         } else {
-            const int h = SNAP_HEIGHT * count + MARGIN * 2 + SPACING * (count - 1);
-            const int w = SNAP_WIDTH + MARGIN * 2;
-
-            m_windowListWidget->setFixedSize(w, h);
-            setFixedSize(w, qMin(h, screenHeight));
+            //dock栏在左右
+            auto funcHeightSum = [ this ]()-> const int {
+                int snapshotSumHeight = 0;
+                for(auto snapshot : m_snapshots) {
+                    snapshotSumHeight += qMin(qMax(snapshot->height(), MIN_SNAP_SIZE), SNAP_HEIGHT_VERTICAL);
+                }
+                return snapshotSumHeight;
+            };
+            const int hightSum = funcHeightSum();
+            m_windowListWidget->setFixedSize(SNAP_WIDTH_VERTICAL, hightSum);
+            setFixedSize(SNAP_WIDTH_VERTICAL, qMin(hightSum, screenHeight));
         }
     } else if (m_windowListLayout->count()) {
         // 2D
@@ -266,7 +285,6 @@ void PreviewContainer::appendSnapWidget(const WId wid)
     connect(snap, &AppSnapshot::requestCloseAppSnapshot, this, &PreviewContainer::onRequestCloseAppSnapshot);
 
     m_snapshots.insert(wid, snap);
-    m_windowListLayout->addWidget(snap);
 }
 
 void PreviewContainer::enterEvent(QEvent *e)
@@ -376,6 +394,9 @@ void PreviewContainer::onSnapshotClicked(const WId wid)
         /* BUGFIX-159303 本地发现该问题仅在wayland下出现，问题已与窗管对接沟通过，根据窗管建议，上层进
         规避，避免因底层强行修改引入新的问题 */
         Q_EMIT requestCancelPreviewWindow();
+        // FIXME: 在预览点击预览图时，会先调用CancelPreview，再调用ActivateWindow,但实际窗管收到的调用顺序是反过来的
+        //        和窗管联合分析后暂时未能找到根因，中间涉及多个组件的调用中转。先添加延迟确保下调用顺序正常
+        QThread::msleep(100);
     }
 
     Q_EMIT requestActivateWindow(wid);
@@ -402,6 +423,34 @@ void PreviewContainer::previewEntered(const WId wid)
     m_currentWId = wid;
     m_floatingPreview->trackWindow(snap);
 
+    // 判断snap是否在m_scrollArea中完全显示，
+    const QRect snapGeometry = m_floatingPreview->trackedWindow()->geometry();
+    const QPoint topLeft = m_windowListWidget->mapTo(m_scrollArea, snapGeometry.topLeft());
+    const QPoint bottomRight = m_windowListWidget->mapTo(m_scrollArea, snapGeometry.bottomRight());
+
+    QScrollBar *scrollBar = m_windowListLayout->direction() == Qt::LeftToRight ?
+                            m_scrollArea->horizontalScrollBar() : m_scrollArea->verticalScrollBar();
+
+    const int currValue = scrollBar->value();
+    const QRect scrollBarRect = scrollBar->rect();
+
+    // 预览界面在m_scrollArea中没有完全显示时，自动移动滚动条
+    // 如果topLeft不在显示区域，则向上或左移动滚动条
+    // bottomRight不在显示区域，则向下或右移动滚动条
+    if (!m_scrollArea->rect().contains(topLeft)) {
+        int offVal = currValue + topLeft.y();
+        if (m_windowListLayout->direction() == Qt::LeftToRight) {
+            offVal = currValue + topLeft.x();
+        }
+        scrollBar->setValue(offVal);
+    } else if (!m_scrollArea->rect().contains(bottomRight)) {
+        int offVal = currValue + bottomRight.y() - scrollBarRect.height();
+        if (m_windowListLayout->direction() == Qt::LeftToRight) {
+            offVal = currValue + bottomRight.x() - scrollBarRect.width();
+        }
+        scrollBar->setValue(offVal);
+    }
+
     if (m_waitForShowPreviewTimer->isActive()) {
         return;
     }
