@@ -158,12 +158,15 @@ int main(int argc, char *argv[])
     DGuiApplicationHelper::setAttribute(DGuiApplicationHelper::UseInactiveColorGroup, false);
     DockApplication app(argc, argv);
 
-    //崩溃信号
-    signal(SIGSEGV, sig_crash);
-    signal(SIGILL,  sig_crash);
-    signal(SIGINT,  sig_crash);
-    signal(SIGABRT, sig_crash);
-    signal(SIGFPE,  sig_crash);
+    QScopedPointer<DConfig> config(DConfig::create("org.deepin.dde.dock", "org.deepin.dde.dock"));
+    if (config->isValid() && config->keyList().contains("enableSafeMode") && config->value("enableSafeMode").toBool()) {
+        //崩溃信号
+        signal(SIGSEGV, sig_crash);
+        signal(SIGILL,  sig_crash);
+        signal(SIGINT,  sig_crash);
+        signal(SIGABRT, sig_crash);
+        signal(SIGFPE,  sig_crash);
+    }
 
     app.setOrganizationName("deepin");
     app.setApplicationName("dde-dock");
@@ -173,7 +176,7 @@ int main(int argc, char *argv[])
     app.setAttribute(Qt::AA_EnableHighDpiScaling, true);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-    // 自动化标记由此开始
+    // 自动化标记
     QAccessible::installFactory(accessibleFactory);
 
     // 设置日志输出到控制台以及文件
