@@ -16,7 +16,7 @@
 
 DWIDGET_USE_NAMESPACE
 
-DockPopupWindow::DockPopupWindow(QWidget *parent)
+DockPopupWindow::DockPopupWindow(QWidget *parent, bool noFocus)
     : DArrowRectangle(ArrowBottom, parent),
       m_model(false),
       m_regionInter(new DRegionMonitor(this)),
@@ -26,15 +26,20 @@ DockPopupWindow::DockPopupWindow(QWidget *parent)
     m_wmHelper = DWindowManagerHelper::instance();
 
     compositeChanged();
-
-    setWindowFlags(Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint | Qt::WindowDoesNotAcceptFocus);
+    setWindowFlags(Qt::X11BypassWindowManagerHint);
     if (Utils::IS_WAYLAND_DISPLAY) {
         setAttribute(Qt::WA_NativeWindow);
-        // 谨慎修改层级，特别要注意对锁屏的影响
-        windowHandle()->setProperty("_d_dwayland_window-type", "dock");
     } else {
         setAttribute(Qt::WA_InputMethodEnabled, false);
     }
+    if (noFocus) {
+        setWindowFlag(Qt::WindowDoesNotAcceptFocus);
+        setWindowFlag(Qt::WindowStaysOnTopHint);
+        if (Utils::IS_WAYLAND_DISPLAY) {
+            // 谨慎修改层级，特别要注意对锁屏的影响
+            windowHandle()->setProperty("_d_dwayland_window-type", "dock");
+        }
+    }
 
     connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, this, &DockPopupWindow::compositeChanged);
     connect(m_regionInter, &DRegionMonitor::buttonRelease, this, &DockPopupWindow::onGlobMouseRelease);
