@@ -1,23 +1,6 @@
-﻿/*
- * Copyright (C) 2018 ~ 2020 Deepin Technology Co., Ltd.
- *
- * Author:     fanpengcheng <fanpengcheng_cm@deepin.com>
- *
- * Maintainer: fanpengcheng <fanpengcheng_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+﻿// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "multiscreenworker.h"
 #include "mainwindow.h"
@@ -42,6 +25,7 @@
 const QString MonitorsSwitchTime = "monitorsSwitchTime";
 const QString OnlyShowPrimary = "onlyShowPrimary";
 
+#define WINDOW_MARGIN ((m_displayMode == Dock::Efficient) ? 0 : 10)
 #define DIS_INS DisplayManager::instance()
 
 // 保证以下数据更新顺序(大环节顺序不要变，内部还有一些小的调整，比如任务栏显示区域更新的时候，里面内容的布局方向可能也要更新...)
@@ -610,7 +594,7 @@ void MultiScreenWorker::onRequestUpdateRegionMonitor()
     }
 
     // 触屏监控高度固定调整为最大任务栏高度100+任务栏与屏幕边缘间距
-    const int monitHeight = 100 + WINDOWMARGIN;
+    const int monitHeight = 100 + WINDOW_MARGIN;
 
     // 任务栏触屏唤起区域
     m_touchRectList.clear();
@@ -829,6 +813,10 @@ void MultiScreenWorker::onRequestNotifyWindowManager()
             break;
         }
 
+        // 加上边距(时尚模式为10+10, 高效模式为0)
+        varList[1] = varList[1].toDouble() + WINDOW_MARGIN * ratio * 2;
+        qDebug() << "Dock strut: " << varList;
+
         if (parent()->windowHandle()->handle()) {
             QGuiApplication::platformNativeInterface()->setWindowProperty(parent()->windowHandle()->handle(),"_d_dwayland_dockstrut", varList);
         }
@@ -874,7 +862,7 @@ void MultiScreenWorker::onRequestNotifyWindowManager()
         }
 
         XcbMisc::instance()->set_strut_partial(static_cast<xcb_window_t>(parent()->winId()), orientation,
-                                               static_cast<uint>(strut + WINDOWMARGIN * ratio), // 设置窗口与屏幕边缘距离，需要乘缩放
+                                               static_cast<uint>(strut + WINDOW_MARGIN * ratio), // 设置窗口与屏幕边缘距离，需要乘缩放
                                                static_cast<uint>(strutStart),                   // 设置任务栏起点坐标（上下为x，左右为y）
                                                static_cast<uint>(strutEnd));                    // 设置任务栏终点坐标（上下为x，左右为y）
     }
@@ -895,7 +883,11 @@ void MultiScreenWorker::onRequestUpdatePosition(const Position &fromPos, const P
 
 void MultiScreenWorker::onRequestUpdateMonitorInfo()
 {
-    resetDockScreen();
+    // resetDockScreen 调用太频繁，未在合适的时机调用时出现 wayland set_position 数值异常
+    // 推测是 qt 未能正确传递窗口位置到 waylandserver， 此处修改经过测试可以较好的规避此问题。
+    // for test ： DOCK_RESET_NOW=true dde-dock
+    if (qEnvironmentVariableIsSet("DOCK_RESET_NOW"))
+        resetDockScreen(); // m_monitorUpdateTimer timeout will call resetDockScreen
 
     // 只需要在屏幕信息变化的时候更新，其他时间不需要更新
     onRequestUpdateRegionMonitor();
@@ -1337,6 +1329,8 @@ void MultiScreenWorker::resetDockScreen()
     /**
       *注意这里要先对parent()进行setFixedSize，在分辨率切换过程中，setGeometry可能会导致其大小未改变
       */
+    if (m_ds.current().isEmpty()) // wayland下当没有屏幕时连接时，qt会虚拟一个空的屏幕，空屏幕这里不处理，不然会导致崩溃
+        return;
     parent()->setFixedSize(dockRect(m_ds.current()).size());
     parent()->setGeometry(dockRect(m_ds.current()));
     qDebug() << "update dock geometry: " << dockRect(m_ds.current());
