@@ -803,7 +803,13 @@ void MainPanelControl::startDrag(DockItem *dockItem)
         isNeedBack = true;
     }
 
-    drag->setMimeData(new QMimeData);
+    auto mimeData = new QMimeData;
+    QByteArray data;
+    QDataStream dataStream(&data, QIODevice::ReadWrite);
+    dataStream << pixmap;
+    mimeData->setData("application/x-desktop", data);
+    drag->setMimeData(mimeData);
+
     drag->exec(Qt::MoveAction);
 
     if (item->itemType() != DockItem::App || m_dragIndex == -1) {
@@ -971,8 +977,8 @@ void MainPanelControl::paintEvent(QPaintEvent *event)
     }
 
     painter.fillRect(m_fixedSpliter->geometry(), color);
-    painter.fillRect(m_appSpliter->geometry(), color);
-    painter.fillRect(m_traySpliter->geometry(), color);
+    painter.fillRect(m_appSpliter->geometry(), m_trayAreaLayout->count() > 0 ? color : Qt::transparent);
+    painter.fillRect(m_traySpliter->geometry(), m_pluginLayout->count() > 0 ? color : Qt::transparent);
 }
 
 /**重新计算任务栏上应用图标、插件图标的大小，并设置
@@ -1211,3 +1217,31 @@ bool MainPanelControl::appIsOnDock(const QString &appDesktop)
 {
     return DockItemManager::instance()->appIsOnDock(appDesktop);
 }
+
+void MainPanelControl::setKwinAppItemMinimizedGeometry(DockItem *item, const QRect r)
+{
+    // 只处理wayland窗口
+    if (!Utils::IS_WAYLAND_DISPLAY) {
+        return;
+    }
+
+    // 对于wayland应用窗口，需要将窗口的位置传递给窗管，用于设置窗口最小化的位置
+    auto w = static_cast<QWidget *>(parent());
+    const auto ratio = devicePixelRatioF();
+    if (item->itemType() == DockItem::App && w->windowHandle() && w->windowHandle()->handle()) {
+        AppItem * appItem = dynamic_cast<AppItem *>(item);
+        if (!appItem) {
+            qWarning() << "invalid item";
+            return;
+        }
+
+        QList<QVariant> varList = {0, 0, 0, 0, 0};
+        varList[0] = appItem->getAppItemWindowId();
+        // 此处传给窗管的坐标需要去掉缩放因子，防止最小化窗口位置错误
+        varList[1] = (r.x() - w->geometry().x()) * ratio;
+        varList[2] = (r.y() - w->geometry().y()) * ratio;
+        varList[3] = r.width();
+        varList[4] = r.height();
+        QGuiApplication::platformNativeInterface()->setWindowProperty(w->windowHandle()->handle(), "_d_dwayland_dock-appitem-geometry", varList);
+    }
+}
