@@ -15,6 +15,7 @@
 #include <QPainter>
 #include <QJsonDocument>
 #include <QDBusConnection>
+#include <QIcon>
 
 DGUI_USE_NAMESPACE
 
@@ -29,6 +30,10 @@ AirplaneModeItem::AirplaneModeItem(QWidget *parent)
                                                "/com/deepin/daemon/AirplaneMode",
                                                QDBusConnection::systemBus(),
                                                this))
+    , m_login1Manager(new Login1Manager("org.freedesktop.login1",
+                                        "/org/freedesktop/login1",
+                                        QDBusConnection::systemBus(),
+                                        this))
 {
     m_tipsLabel->setText(tr("Airplane mode enabled"));
     m_tipsLabel->setVisible(false);
@@ -37,12 +42,22 @@ AirplaneModeItem::AirplaneModeItem(QWidget *parent)
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &AirplaneModeItem::refreshIcon);
     connect(m_applet, &AirplaneModeApplet::enableChanged, m_airplaneModeInter, &DBusAirplaneMode::Enable);
     connect(m_airplaneModeInter, &DBusAirplaneMode::EnabledChanged, this, [this](bool enable) {
-        m_applet->setEnabled(enable);
+        m_applet->setEnabled(m_airplaneModeInter->enabled());
         refreshIcon();
         Q_EMIT airplaneEnableChanged(enable);
         updateTips();
     });
 
+    connect(m_login1Manager, &Login1Manager::PrepareForSleep, this, [ = ] (bool sleep) {
+        if (!sleep) {
+            const bool enabled = m_airplaneModeInter->enabled();
+            m_applet->setEnabled(enabled);
+            refreshIcon();
+            Q_EMIT airplaneEnableChanged(enabled);
+            updateTips();
+        }
+    });
+
     m_applet->setEnabled(m_airplaneModeInter->enabled());
     refreshIcon();
     updateTips();
@@ -112,11 +127,14 @@ void AirplaneModeItem::refreshIcon()
     else
         iconString = "airplane-off";
 
-    const auto ratio = devicePixelRatioF();
-    int iconSize = PLUGIN_ICON_MAX_SIZE;
     if (height() <= PLUGIN_BACKGROUND_MIN_SIZE && DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
         iconString.append(PLUGIN_MIN_ICON_NAME);
-    m_iconPixmap = ImageUtil::loadSvg(iconString, ":/", iconSize, ratio);
+
+    const auto ratio = devicePixelRatioF();
+    QSize pixmapSize = QCoreApplication::testAttribute(Qt::AA_UseHighDpiPixmaps) ? QSize(20, 20) : (QSize(20, 20) * ratio);
+    m_iconPixmap = QIcon::fromTheme(iconString, QIcon::fromTheme("://" + iconString + ".svg")).pixmap(pixmapSize);
+    m_iconPixmap.setDevicePixelRatio(ratio);
+
     update();
 }
 
@@ -153,8 +171,10 @@ void AirplaneModeItem::paintEvent(QPaintEvent *e)
 {
     QWidget::paintEvent(e);
 
+    const auto ratio = devicePixelRatioF();
+
     QPainter painter(this);
     const QRectF &rf = QRectF(rect());
     const QRectF &rfp = QRectF(m_iconPixmap.rect());
-    painter.drawPixmap(rf.center() - rfp.center() / m_iconPixmap.devicePixelRatioF(), m_iconPixmap);
+    painter.drawPixmap(rf.center() - rfp.center() / ratio, m_iconPixmap);
 }
