@@ -6,10 +6,12 @@
 #define AIRPLANEMODEITEM_H
 
 #include <com_deepin_daemon_airplanemode.h>
+#include <org_freedesktop_login1.h>
 
 #include <QWidget>
 
 using DBusAirplaneMode = com::deepin::daemon::AirplaneMode;
+using Login1Manager = org::freedesktop::login1::Manager;
 
 namespace Dock {
 class TipsWidget;
@@ -43,6 +45,7 @@ private:
     Dock::TipsWidget *m_tipsLabel;
     AirplaneModeApplet *m_applet;
     DBusAirplaneMode *m_airplaneModeInter;
+    Login1Manager *m_login1Manager;
     QPixmap m_iconPixmap;
 };
 
