@@ -23,7 +23,7 @@ BluetoothDeviceItem::BluetoothDeviceItem(QStyle *style, const Device *device, DL
     : m_style(style)
     , m_device(device)
     , m_standarditem(new DStandardItem())
-    , m_labelAction(nullptr)
+    , m_iconAction(nullptr)
     , m_stateAction(nullptr)
     , m_connAction(nullptr)
     , m_loading(new DSpinner(parent->viewport()))
@@ -49,7 +49,7 @@ BluetoothDeviceItem::~BluetoothDeviceItem()
 
 void BluetoothDeviceItem::initActionList()
 {
-    m_labelAction = new DViewItemAction(Qt::AlignLeft | Qt::AlignVCenter, QSize(), QSize(), false);
+    m_iconAction = new DViewItemAction(Qt::AlignLeft | Qt::AlignVCenter, QSize(), QSize(), false);
     m_stateAction = new DViewItemAction(Qt::AlignLeft | Qt::AlignVCenter, QSize(), QSize(), true);
     m_connAction = new DViewItemAction(Qt::AlignRight | Qt::AlignVCenter, QSize(16, 16), QSize(16, 16), false);
 
@@ -69,11 +69,11 @@ void BluetoothDeviceItem::initActionList()
 
     m_standarditem->setAccessibleText(m_device->alias());
     m_standarditem->setActionList(Qt::RightEdge, { m_stateAction, m_connAction });
-    m_standarditem->setActionList(Qt::LeftEdge, { m_labelAction });
+    m_standarditem->setActionList(Qt::LeftEdge, { m_iconAction });
 
     //蓝牙列表可用蓝牙设备信息文字显示高亮
-    m_labelAction->setTextColorRole(DPalette::BrightText);
-    m_labelAction->setText(m_device->alias());
+    m_standarditem->setTextColorRole(DPalette::BrightText);
+    m_standarditem->setText(m_device->alias());
     updateDeviceState(m_device->state());
     updateIconTheme(DGuiApplicationHelper::instance()->themeType());
 }
@@ -100,12 +100,12 @@ void BluetoothDeviceItem::updateIconTheme(DGuiApplicationHelper::ColorType type)
             m_deviceIcon = DarkString.arg("other");
         }
     }
-    m_labelAction->setIcon(QIcon(m_deviceIcon));
+    m_iconAction->setIcon(QIcon(m_deviceIcon));
 }
 
 void BluetoothDeviceItem::updateDeviceState(Device::State state)
 {
-    m_labelAction->setText(m_device->alias());
+    m_standarditem->setText(m_device->alias());
 
     m_connAction->setVisible(state == Device::StateConnected);
     m_stateAction->setVisible(state == Device::StateAvailable);
@@ -139,6 +139,7 @@ BluetoothAdapterItem::BluetoothAdapterItem(Adapter *adapter, QWidget *parent)
     , m_refreshBtn(new RefreshButton(this))
     , m_bluetoothInter(new DBusBluetooth("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this))
     , m_showUnnamedDevices(false)
+    , m_stateBtnEnabled(true)
     , m_seperator(new HorizontalSeperator(this))
 {
     initData();
@@ -226,6 +227,17 @@ QStringList BluetoothAdapterItem::connectedDevicesName()
     return devsName;
 }
 
+void BluetoothAdapterItem::setStateBtnEnabled(bool enable)
+{
+    if (m_stateBtnEnabled != enable) {
+        m_stateBtnEnabled = enable;
+    }
+
+    if (m_adapterStateBtn) {
+        m_adapterStateBtn->setEnabled(m_stateBtnEnabled);
+    }
+}
+
 void BluetoothAdapterItem::initData()
 {
     m_showUnnamedDevices = m_bluetoothInter->displaySwitch();
@@ -381,7 +393,7 @@ void BluetoothAdapterItem::initConnect()
         m_deviceListview->setVisible(state);
         m_seperator->setVisible(state);
         m_adapterStateBtn->setChecked(state);
-        m_adapterStateBtn->setEnabled(true);
+        m_adapterStateBtn->setEnabled(m_stateBtnEnabled);
         emit adapterPowerChanged();
     });
     connect(m_adapterStateBtn, &DSwitchButton::clicked, this, [ = ](bool state) {
