@@ -201,6 +201,7 @@ void PowerPlugin::loadPlugin()
     });
     connect(m_systemPowerInter, &SystemPowerInter::BatteryTimeToEmptyChanged, this, &PowerPlugin::refreshTipsData);
     connect(m_systemPowerInter, &SystemPowerInter::BatteryTimeToFullChanged, this, &PowerPlugin::refreshTipsData);
+    connect(m_systemPowerInter, &SystemPowerInter::BatteryPercentageChanged, this, &PowerPlugin::refreshTipsData);
 
     connect(m_powerInter, &DBusPower::BatteryPercentageChanged, this, &PowerPlugin::updateBatteryVisible);
 
@@ -238,8 +239,7 @@ void PowerPlugin::onGSettingsChanged(const QString &key)
 
 void PowerPlugin::refreshTipsData()
 {
-    const BatteryPercentageMap data = m_powerInter->batteryPercentage();
-    const uint percentage = qMin(100.0, qMax(0.0, data.value("Display")));
+    const uint percentage = qMin(100.0, qMax(0.0, m_systemPowerInter->batteryPercentage()));
     const QString value = QString("%1%").arg(std::round(percentage));
     const int batteryState = m_powerInter->batteryState()["Display"];
 
@@ -259,7 +259,7 @@ void PowerPlugin::refreshTipsData()
         uint sencond = time.toString("ss").toInt();
         if (sencond > 0)
             min += 1;
-        if (!m_showTimeToFull) {
+        if (!m_showTimeToFull || timeToEmpty == 0) {
             tips = tr("Capacity %1").arg(value);
         } else {
             if (hour == 0) {
