@@ -270,6 +270,9 @@ void SoundApplet::onDefaultSinkChanged()
     connect(m_defSinkInter, &DBusSink::MuteChanged, this, [ = ] {
         onVolumeChanged(existActiveOutputDevice() ? m_defSinkInter->volume() : 0);
     });
+    connect(m_defSinkInter, &DBusSink::ActivePortChanged, this, [ = ](AudioPort  port){
+        activePort(port.name, m_defSinkInter->card());
+    });
 
     QString portId = m_defSinkInter->activePort().name;
     uint cardId = m_defSinkInter->card();
