@@ -107,6 +107,7 @@ SNITrayWidget::SNITrayWidget(const QString &sniServicePath, QWidget *parent)
     connect(m_sniInter, &StatusNotifierItem::OverlayIconNameChanged, this, &SNITrayWidget::onSNIOverlayIconNameChanged);
     connect(m_sniInter, &StatusNotifierItem::OverlayIconPixmapChanged, this, &SNITrayWidget::onSNIOverlayIconPixmapChanged);
     connect(m_sniInter, &StatusNotifierItem::StatusChanged, this, &SNITrayWidget::onSNIStatusChanged);
+    connect(this, &SNITrayWidget::requestShowMenu, this, &SNITrayWidget::showContextMenu);
 
     // the following signals can be emit automatically
     // need refresh cached properties in these slots
@@ -160,7 +161,7 @@ void SNITrayWidget::sendClick(uint8_t mouseButton, int x, int y)
             // primarily work for apps using libappindicator.
             reply.waitForFinished();
             if (reply.isError()) {
-                showContextMenu(x,y);
+                Q_EMIT requestShowMenu(x, y);
             }
         });
     }
@@ -630,6 +631,16 @@ void SNITrayWidget::showHoverTips()
     if (PopupWindow->model())
         return;
 
+    if (DWindowManagerHelper::instance()->hasComposite()) {
+        PopupWindow.data()->setRadiusArrowStyleEnable(true);
+        PopupWindow.data()->setArrowWidth(14);
+        PopupWindow.data()->setArrowHeight(10);
+    } else {
+        PopupWindow.data()->setRadiusArrowStyleEnable(false);
+        PopupWindow.data()->setArrowWidth(20);
+        PopupWindow.data()->setArrowHeight(10);
+    }
+
     // if not in geometry area
     const QRect r(topleftPoint(), size());
     if (!r.contains(QCursor::pos()))
