@@ -10,8 +10,116 @@
 
 #include <xcb/xproto.h>
 
+// 网络面板需要输入焦点，"_d_dwayland_window-type"属性不支持动态改变，所以需要处理两个PopupWindow切换
+class SystemTrayItem::PopupWindowManager : public QObject
+{
+public:
+    PopupWindowManager(QWidget *parent = nullptr)
+        : QObject(parent)
+        , m_appletPopup(createPopupWindow(false))
+        , m_tipsPopup(createPopupWindow(true))
+        , m_currentPopup(m_appletPopup)
+    {
+        m_appletPopup->setObjectName("systemtraypopup");
+        m_tipsPopup->setObjectName("systemtraytipspopup");
+    }
+    ~PopupWindowManager()
+    {
+        m_currentPopup = nullptr;
+        delete m_appletPopup;
+        m_appletPopup = nullptr;
+        delete m_tipsPopup;
+        m_tipsPopup = nullptr;
+    }
+    inline DockPopupWindow *appletPopup() const
+    {
+        return m_appletPopup;
+    }
+    inline DockPopupWindow *toAppletPopup(SystemTrayItem *item)
+    {
+        return toPopup(m_appletPopup, item);
+    }
+    inline DockPopupWindow *toTipsPopup(SystemTrayItem *item)
+    {
+        return toPopup(m_tipsPopup, item);
+    }
+    inline DockPopupWindow *data() const { return m_currentPopup; }
+
+    bool model() const
+    {
+        return m_currentPopup->model();
+    }
+    void hide() const
+    {
+        m_currentPopup->hide();
+    }
+    void accept() const
+    {
+        emit m_currentPopup->accept();
+    }
+    bool isVisible() const
+    {
+        return m_currentPopup->isVisible();
+    }
+    QWidget *getContent() const
+    {
+        return m_currentPopup->getContent();
+    }
+    void show(const QPoint &pos, const bool model = false)
+    {
+        m_currentPopup->show(pos, model);
+    }
+    void disconnectAccept(SystemTrayItem *item) const
+    {
+        disconnect(m_currentPopup, &DockPopupWindow::accept, item, &SystemTrayItem::popupWindowAccept);
+    }
+    void connectAccept(SystemTrayItem *item) const
+    {
+        connect(m_currentPopup, &DockPopupWindow::accept, item, &SystemTrayItem::popupWindowAccept, Qt::UniqueConnection);
+    }
+
+private:
+    DockPopupWindow *createPopupWindow(bool noFocus) const
+    {
+        DockPopupWindow *arrowRectangle = new DockPopupWindow(nullptr, noFocus);
+        arrowRectangle->setShadowBlurRadius(20);
+        arrowRectangle->setRadius(6);
+        arrowRectangle->setShadowYOffset(2);
+        arrowRectangle->setShadowXOffset(0);
+        arrowRectangle->setArrowWidth(18);
+        arrowRectangle->setArrowHeight(10);
+        connect(qApp, &QApplication::aboutToQuit, arrowRectangle, &DockPopupWindow::deleteLater);
+        return arrowRectangle;
+    }
+    inline DockPopupWindow *toPopup(DockPopupWindow *popup, SystemTrayItem *item)
+    {
+        if (m_currentPopup != popup) {
+            disconnectAccept(item);
+            m_currentPopup->hide();
+            m_currentPopup = popup;
+        }
+
+        if (DWindowManagerHelper::instance()->hasComposite()) {
+            m_currentPopup->setRadiusArrowStyleEnable(true);
+            m_currentPopup->setArrowWidth(14);
+            m_currentPopup->setArrowHeight(10);
+        } else {
+            m_currentPopup->setRadiusArrowStyleEnable(false);
+            m_currentPopup->setArrowWidth(20);
+            m_currentPopup->setArrowHeight(10);
+        }
+
+        return m_currentPopup;
+    }
+
+private:
+    DockPopupWindow *m_appletPopup;
+    DockPopupWindow *m_tipsPopup;
+    DockPopupWindow *m_currentPopup;
+};
+
 Dock::Position SystemTrayItem::DockPosition = Dock::Position::Top;
-QPointer<DockPopupWindow> SystemTrayItem::PopupWindow = nullptr;
+QPointer<SystemTrayItem::PopupWindowManager> SystemTrayItem::PopupWindow = nullptr;
 
 SystemTrayItem::SystemTrayItem(PluginsItemInterface *const pluginInter, const QString &itemKey, QWidget *parent)
     : AbstractTrayWidget(parent)
@@ -40,21 +148,12 @@ SystemTrayItem::SystemTrayItem(PluginsItemInterface *const pluginInter, const QS
     setAttribute(Qt::WA_TranslucentBackground);
 
     if (PopupWindow.isNull()) {
-        DockPopupWindow *arrowRectangle = new DockPopupWindow(nullptr);
-        arrowRectangle->setShadowBlurRadius(20);
-        arrowRectangle->setRadius(6);
-        arrowRectangle->setShadowYOffset(2);
-        arrowRectangle->setShadowXOffset(0);
-        arrowRectangle->setArrowWidth(18);
-        arrowRectangle->setArrowHeight(10);
-        arrowRectangle->setObjectName("systemtraypopup");
-        PopupWindow = arrowRectangle;
-        connect(qApp, &QApplication::aboutToQuit, PopupWindow, &DockPopupWindow::deleteLater);
+        PopupWindow = new PopupWindowManager(nullptr);
     }
 
     // 必须初始化父窗口，否则当主题切换之后再设置父窗口的时候palette会更改为主题切换前的palette
     if (QWidget *w = m_pluginInter->itemPopupApplet(m_itemKey)) {
-        w->setParent(PopupWindow.data());
+        w->setParent(PopupWindow->appletPopup());
         w->setVisible(false);
     }
 
@@ -203,7 +302,7 @@ void SystemTrayItem::mousePressEvent(QMouseEvent *event)
     hideNonModel();
 
     if (event->button() == Qt::RightButton
-            && perfectIconRect().contains(event->pos(), true)) {
+        && perfectIconRect().contains(event->pos(), true)) {
         return (m_gsettings && (!m_gsettings->keys().contains("menuEnable") || m_gsettings->get("menuEnable").toBool())) ? showContextMenu() : void();
     }
 
@@ -290,13 +389,13 @@ void SystemTrayItem::hidePopup()
     m_popupShown = false;
     PopupWindow->hide();
 
-    DockPopupWindow *popup = PopupWindow.data();
+    DockPopupWindow *popup = PopupWindow->data();
     QWidget *content = popup->getContent();
     if (content) {
         content->setVisible(false);
     }
 
-    emit PopupWindow->accept();
+    PopupWindow->accept();
     emit requestWindowAutoHide(true);
 }
 
@@ -312,7 +411,7 @@ void SystemTrayItem::popupWindowAccept()
     if (!PopupWindow->isVisible())
         return;
 
-    disconnect(PopupWindow.data(), &DockPopupWindow::accept, this, &SystemTrayItem::popupWindowAccept);
+    PopupWindow->disconnectAccept(this);
 
     hidePopup();
 }
@@ -324,10 +423,13 @@ void SystemTrayItem::showPopupApplet(QWidget *const applet)
 
     // another model popup window already exists
     if (PopupWindow->model()) {
-        applet->setVisible(false);
+        if (PopupWindow->getContent() != applet)
+            applet->setVisible(false);
+
         return;
     }
 
+    PopupWindow->toAppletPopup(this);
     showPopupWindow(applet, true);
 }
 
@@ -339,9 +441,9 @@ void SystemTrayItem::showPopupWindow(QWidget *const content, const bool model)
     if (model)
         emit requestWindowAutoHide(false);
 
-    DockPopupWindow *popup = PopupWindow.data();
+    DockPopupWindow *popup = PopupWindow->data();
     QWidget *lastContent = popup->getContent();
-    if (lastContent)
+    if (lastContent && lastContent != content)
         lastContent->setVisible(false);
 
     switch (DockPosition) {
@@ -359,7 +461,7 @@ void SystemTrayItem::showPopupWindow(QWidget *const content, const bool model)
     else
         popup->show(p, model);
 
-    connect(popup, &DockPopupWindow::accept, this, &SystemTrayItem::popupWindowAccept, Qt::UniqueConnection);
+    PopupWindow->connectAccept(this);
 }
 
 void SystemTrayItem::showHoverTips()
@@ -377,6 +479,7 @@ void SystemTrayItem::showHoverTips()
     if (!content)
         return;
 
+    PopupWindow->toTipsPopup(this);
     showPopupWindow(content);
 }
 
@@ -411,7 +514,6 @@ void SystemTrayItem::showContextMenu()
     if (menuJson.isEmpty())
         return;
 
-
     QJsonDocument jsonDocument = QJsonDocument::fromJson(menuJson.toLocal8Bit().data());
     if (jsonDocument.isNull())
         return;
@@ -467,7 +569,8 @@ void SystemTrayItem::updatePopupPosition()
     PopupWindow->show(p, PopupWindow->model());
 }
 
-void SystemTrayItem::onGSettingsChanged(const QString &key) {
+void SystemTrayItem::onGSettingsChanged(const QString &key)
+{
     if (key != "enable") {
         return;
     }
