@@ -91,8 +91,10 @@ private:
     QPointer<QWidget> m_lastPopupWidget;
     QString m_itemKey;
 
+    class PopupWindowManager;
+
     static Dock::Position DockPosition;
-    static QPointer<DockPopupWindow> PopupWindow;
+    static QPointer<PopupWindowManager> PopupWindow;
     const QGSettings* m_gsettings;
 };
 
