@@ -305,6 +305,11 @@ void XEmbedTrayWidget::sendHoverEvent()
     if (!rect().contains(mapFromGlobal(QCursor::pos()))) {
         return;
     }
+    auto c = IS_WAYLAND_DISPLAY ? m_xcbCnn : QX11Info::connection();
+    if (!c) {
+        qWarning() << "QX11Info::connection() is " << c;
+        return;
+    }
 
     const QPoint p(rawXPosition(QCursor::pos()));
     configContainerPosition();
@@ -318,7 +323,6 @@ void XEmbedTrayWidget::sendHoverEvent()
             XFlush(display);
         } else {
             // 发送 montion notify event到client，实现hover事件
-            auto c = QX11Info::connection();
             xcb_motion_notify_event_t* event = new xcb_motion_notify_event_t;
             memset(event, 0x00, sizeof(xcb_motion_notify_event_t));
             event->response_type = XCB_MOTION_NOTIFY;
@@ -367,7 +371,7 @@ void XEmbedTrayWidget::sendClick(uint8_t mouseButton, int x, int y)
         return;
 
     m_sendHoverEvent->stop();
-    auto c = QX11Info::connection();
+    auto c = IS_WAYLAND_DISPLAY ? m_xcbCnn : QX11Info::connection();
     if (!c) {
         qWarning() << "QX11Info::connection() is " << c;
         return;
@@ -379,7 +383,7 @@ void XEmbedTrayWidget::sendClick(uint8_t mouseButton, int x, int y)
 
     Display *display = IS_WAYLAND_DISPLAY ? m_display : QX11Info::display();
 
-    if (m_injectMode == XTest) {
+    if (m_injectMode == XTest || IS_WAYLAND_DISPLAY) {
         XTestFakeMotionEvent(display, 0, p.x(), p.y(), CurrentTime);
         XFlush(display);
         XTestFakeButtonEvent(display, mouseButton, true, CurrentTime);
@@ -661,4 +665,4 @@ uint XEmbedTrayWidget::getWindowPID(uint winId)
         XCloseDisplay(display);
 
     return pid;
-}
\ No newline at end of file
+}
